Class: Spotify::Models::Simplified::Album

Inherits:
Album
  • Object
show all
Defined in:
lib/spotify/models/simplified/album.rb

Overview

This class is kept only to provide a better visualization.

Instance Attribute Summary

Attributes inherited from Album

#album_type, #available_markets, #external_urls, #genres, #href, #id, #images, #name, #type, #uri

Instance Method Summary collapse

Constructor Details

#initialize(args = {}) ⇒ Simplified::Album

Sets the arguments to its variables.

Parameters:

  • args (Hash) (defaults to: {})

    the arguments that will be placed on each variable.



17
# File 'lib/spotify/models/simplified/album.rb', line 17

def initialize(args = {}); super(args); end